# kktools


========

This library provides python tools for finance and treasury specialists.

## Installation

`pip install kktools`

## Realized Functionality
`get_ecb_rates("CUR", "YYYY-MM-DD")` - returns pandas dataframe with historical values for a given currency ("CUR") starting from the given date.<br>
`get_last_ecb_rates()` - returns pandas dataframe with the latest valid ECB exchange rates for all published currencies.<br>
`df_to_excel("file_name.xlsx", dataframe)` - exports pandas dataframe to an excel file with pretty formatting.<br>
`dfs_to_excel("file_name.xlsx", list_of_dataframes)` - exports list of pandas dataframes to an excel file with pretty formatting.<br>
`Camt053` - class for parsing CAMT053 files (EOD bank statements, ISO20022 standard).<br>
`Pain001` - class for parsing PAIN001 files (payment initiation, ISO20022 standard).

## Basic Usage

Importing history of EUR/GBP exchange rates since 2000-01-01 and exporting it to an excel file with pretty formatting

```
import kktools as kkt

df = kkt.get_ecb_rates("GBP", "2000-01-01")
kkt.df_to_excel("Historical_Rates.xlsx", df)
```

Parsing CAMT053 file and getting list of balances and list of all transactions:
```
from kktools import Camt053

camt = Camt053(file_name) # creates an object of Camt class you need to pass path+file_name of the CAMT053 file to be processed
camt.camt.statements_info # returns list of dictionaries for each statement with the following information: account id and owner name, all available balances (OPBD/CLBD/CLAV/PRCD/FWAV/etc.), 
camt.transactions # returns list of all transactions in the file.

```

### License
MIT licensed. Check the [`LICENSE`](https://github.com/khorevkp/KK_Tools/blob/master/LICENSE) file for full details.
